@@ -1,6 +1,8 @@
 package DBIx::Skinny::Transaction;
 use strict;
 use warnings;
+use Carp ();
+use Try::Tiny;
 
 sub new {
     my($class, $skinny) = @_;
@@ -24,14 +26,13 @@ sub DESTROY {
     my($dismiss, $skinny) = @{ $_[0] };
     return if $dismiss;
 
-    {
-        local $@;
-        eval { $skinny->txn_rollback };
-        my $rollback_exception = $@;
-        if($rollback_exception) {
-            die "Rollback failed: ${rollback_exception}";
-        }
-    }
+    Carp::carp('do rollback');
+
+    try {
+        $skinny->txn_rollback;
+    } catch {
+        die "Rollback failed: $_";
+    };
 }
 
 1;
